@@ -13,10 +13,13 @@ var hierarchy =
     [ "idiagnl_meminfo", "structidiagnl__meminfo.html", null ],
     [ "idiagnl_req", "structidiagnl__req.html", null ],
     [ "idiagnl_vegasinfo", "structidiagnl__vegasinfo.html", null ],
+    [ "ila_tunnel_encap", "structila__tunnel__encap.html", null ],
     [ "inet6_data", "structinet6__data.html", null ],
     [ "ip6_tnl_info", "structip6__tnl__info.html", null ],
+    [ "ip6_tunnel_encap", "structip6__tunnel__encap.html", null ],
     [ "ip6gre_info", "structip6gre__info.html", null ],
     [ "ip6vti_info", "structip6vti__info.html", null ],
+    [ "ip_tunnel_encap", "structip__tunnel__encap.html", null ],
     [ "ipgre_info", "structipgre__info.html", null ],
     [ "ipip_info", "structipip__info.html", null ],
     [ "ipvti_info", "structipvti__info.html", null ],
@@ -47,6 +50,7 @@ var hierarchy =
     [ "nl_object", null, [
       [ "rtnl_link", "structrtnl__link.html", null ]
     ] ],
+    [ "nl_rhash_table", "structnl__rhash__table.html", null ],
     [ "nl_vf_rate", "structnl__vf__rate.html", null ],
     [ "nl_vf_vlan_info", "structnl__vf__vlan__info.html", null ],
     [ "nl_vf_vlans", "structnl__vf__vlans.html", null ],
@@ -68,7 +72,6 @@ var hierarchy =
     [ "rtnl_mirred", "structrtnl__mirred.html", null ],
     [ "rtnl_neightbl", "structrtnl__neightbl.html", null ],
     [ "rtnl_neightbl_parms", "structrtnl__neightbl__parms.html", null ],
-    [ "rtnl_nexthop", "structrtnl__nexthop.html", null ],
     [ "rtnl_nh_encap", "structrtnl__nh__encap.html", null ],
     [ "rtnl_pktloc", "structrtnl__pktloc.html", null ],
     [ "rtnl_plug", "structrtnl__plug.html", null ],
