@@ -11,6 +11,5 @@ var structnl__dump__params =
     [ "dp_buf", "structnl__dump__params.html#ad069c751442fcf74c9f1bf25f0f5af92", null ],
     [ "dp_buflen", "structnl__dump__params.html#a63a511bbc4d12484ada704dcfc0818c0", null ],
     [ "dp_pre_dump", "structnl__dump__params.html#a08aa2ae4636d506c7b4ccf26f37ee605", null ],
-    [ "dp_ivar", "structnl__dump__params.html#af1f8a5423568e809b67080908eecf6aa", null ],
-    [ "dp_line", "structnl__dump__params.html#a39c27a73728fa5c9ea7b716fe362c0d7", null ]
+    [ "dp_ivar", "structnl__dump__params.html#af1f8a5423568e809b67080908eecf6aa", null ]
 ];
\ No newline at end of file
